# vim: set sw=4 ts=4 et nu:

# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/

Name:           ncdc
Version:        1.17
Release:        1.3
Summary:        Lightweight Direct Connect Client
Source:         http://dev.yorhel.nl/download/ncdc-%{version}.tar.gz
Source1:        ncdc.desktop
Patch1:         ncdc-remove_build_date.patch
URL:            http://dev.yorhel.nl/ncdc
Group:          Productivity/Networking/Other
License:        MIT License
BuildRoot:      %{_tmppath}/build-%{name}-%{version}
BuildRequires:  ncurses-devel
BuildRequires:  libgnutls-devel
BuildRequires:  libbz2-devel
BuildRequires:  glib2-devel
BuildRequires:  libxml2-devel
BuildRequires:  gdbm-devel
BuildRequires:  sqlite-devel
BuildRequires:  zlib-devel
BuildRequires:  gcc make glibc-devel pkgconfig
BuildRequires:  autoconf automake libtool
BuildRequires:  update-desktop-files

%description
Ncdc is a modern and lightweight direct connect client with a friendly ncurses
interface. 

%prep
%setup -q
%patch1

%build
%configure \
    --disable-silent-rules

%__make %{?_smp_flags}

%install
%makeinstall

%__install -D -m0644 "%{SOURCE1}" "%{buildroot}%{_datadir}/applications/%{name}.desktop"
%suse_update_desktop_file -r "%{name}" Network FileTransfer

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%files
%defattr(-,root,root)
%doc ChangeLog COPYING README
%{_bindir}/ncdc
%{_datadir}/applications/%{name}.desktop
%doc %{_mandir}/man1/ncdc.1*

%changelog
* Fri Jul 26 2013 pascal.bleser@opensuse.org
- update to 1.17:
  * Add 'q' key to user list for matching a users' files with download queue
  * Add transfers.log format documentation to manual page
  * Consider non-alphanumeric characters as word separators in input line
  * Fix outgoing UDP messages to respect local_address setting
  * Fix Alt+Backspace on xterm-like terminals
  * Fix handling of "." and ".." file/directory names in files.xml.bz2
  * Fix possible crash when receiving unexpected encrypted search results
  * Fix sendfile() handling to use fallback on EOVERFLOW
  * Fix possible crash when logging UDP messages
* Mon Mar 25 2013 pascal.bleser@opensuse.org
- update to 1.16:
  * List of granted users is now remembered across restarts
  * Don't throttle users who are granted a slot
  * Support CIDs of variable size on ADC
  * Log, but otherwise ignore, DSTA messages on ADC
  * Fix possible crash with graceful disconnect on C-C connections
  * Fix bug with enabling active mode when active_ip is set
  * Fix reporting of active mode on NMDC hubs
  * Fix bug with the 'X' key on the queue tab
  * Fix idle disconnect timeout when a file transfer is active
- changes from 1.15:
  * IPv6 support
  * Significantly shorten certificate creation time with old GnuTLS versions
  * Always enable tls_policy and sudp_policy by default
  * Link against libgcrypt if detected GnuTLS is older than 3.0
  * Add color_tab_active setting
  * Remove active_tls_port setting
  * Allow '-', '.' and '_' characters in hub names
  * Allow spaces before a command
  * Add Alt+backspace as alias for Ctrl+w
  * Add throttle for 'CGET tthl' requests
  * Don't throw away PMs from unknown users
  * Recognize mode field in $MyINFO without tag
  * Fix possible crash with C-C TLS and old GnuTLS versions
  * Fix old references to the removed ncdc-db-upgrade utility
  * Fix loading of file lists from Shareaza 2.6.0.0 and earlier
  * Fix handling of tab and carriage return in log window
  * Fix changing of download_dir/incoming_dir if either dir has been deleted
  * Fix compilation against glib < 2.26
  * Fix unclean C-C TLS disconnect on timeout
* Sun Nov  4 2012 pascal.bleser@opensuse.org
- update to 1.14:
  * added BLOM support for ADC ('/hset adc_blom true' to enable it)
  * added section on connection settings to man page
  * fix incorrect char signedness assumption on ARM
  * fix possible crash when downloading small files
  * fix hub counts reported to the hub on login on ADC
  * removed legacy ncdc-db-upgrade utility
* Mon Aug 20 2012 pascal.bleser@opensuse.org
- update to 1.13:
  * zlib library added as a required dependency
  * Purge empty directories from share by default
  * Added "share_emptydirs" setting
  * Disable tls_policy by default when using an old GnuTLS version
  * Improved support for group chat
  * Honor G_FILENAME_ENCODING for path autocomplete, /share and queued files
  * Use a default connection string on NMDC if no 'connection' has been set
  * Support ZLIG for partial file list transfers on ADC
  * Send more subdirectories in partial file list transfers
  * Removed use of system-provided realpath()
  * Don't allow /search with an empty string
  * Fix segfault on /search command without query
  * Fix display of 'sudp_policy' setting if SUDP is not supported
  * Fix --enable-git-version when cross-compiling
- changes from 1.12:
  * - Don't follow symlinks in share by default
  * - Added 'share_symlink' option
  * - Added bell notification and 'notify_bell' option
  * - Added 'sudp_policy' setting
  * - List all configured hubs on '/open'
  * - Added '/delhub' command to remove hub configuration
  * - Added filtering options to connections tab
  * - Added TLS support indication to user list
  * - Added Alt+a key to cycle through tabs with recent activity
  * - Allow binding to ports below 1024
  * - Add space after autocompleting a command
  * - Fix uploading chunks of 2GiB and larger (bug #12)
  * - Fix bug with duplicate directory detection in '/share'
  * - Fix display of timer on search tab
  * - ADC: Use shorter search token to save some bandwidth
  * - Various attempts at cleaning up some code
* Wed May 16 2012 pascal.bleser@opensuse.org
- update to 1.11:
  * Drop libxml2 in favour of custom XML parser & writer
  * Allow using a single listen port for TCP and TLS
  * Added support for encrypted UDP messages (ADC SUDP)
  * Fix /disconnect to cancel automatic reconnect
  * Fix loading of file lists with invalid UTF-8 sequences
  * Fix use of TLS in passive mode on ADC
* Thu May  3 2012 pascal.bleser@opensuse.org
- update to 1.10:
  * Rewrote network backend to use plain sockets instead of GIO
  * Added GnuTLS as required dependency
  * Removed GIO and glib-networking dependencies
  * Removed 'ncdc-gen-cert' utility - ncdc can now generate certs by itself
  * Enable client-to-client TLS by default
  * Added 'tls_priority' setting
  * Added 'reconnect_timeout' setting
  * Don't quit ncdc on Ctrl+C
  * Display age of file list in the title bar
  * Don't build the 'ncdc-db-upgrade' tool by default
  * Switched to a single top-level Makefile
  * Fix '/browse user -f' ('-f' argument after username)
  * Fix hub login when it checks for public hubs = 0
  * Fix overflow of long tab titles
  * Fix loading of microdc2-generated file lists
  * Fix loading of file lists with an invalid character
  * Fix occasional crash when TLS is enabled
  * Fix transfer rate indication and limiting with TLS connections
  * Fix small memory leak when 'upload_rate' is set
* Thu Mar 15 2012 pascal.bleser@opensuse.org
- update to 1.9:
  * allow all 'active_' settings to be changed on a per-hub basis
  * allow 'active_ip' to be unset and automatically get IP from hub
  * added 'active_udp_port' and 'active_tcp_port' settings
  * renamed 'active_bind' to 'local_address' and use it for outgoing
    connections as well
  * display connection settings in hub info bar
  * added '/listen' command to display currently used ports
  * don't listen on TLS port when tls_policy is disabled
  * added 'disconnect_offline' setting
  * display '(global)' indicator when showing /hset variables
  * don't strip whitespace from /say
  * don't allow directory separator as /share name
  * allow 'global.' and '#hubname.' prefix for /set keys
  * fix display of long IP addresses on user list
* Fri Feb 17 2012 pascal.bleser@opensuse.org
- update to 1.8:
  * added bandwidth limiting (upload_rate and download_rate settings)
  * added hash speed limiting (hash_rate setting)
  * added 'm' key to connection tab to /msg selected user
  * disable client-to-client TLS by default
  * don't throw away some search results on NMDC
  * (partially) fixed uploading of >2GB chunks
  * fixed file descriptor leak when using the backlog feature
  * fixed crash when opening invalid filelist from search twice
  * minor typo fixes
* Sun Jan  1 2012 pascal.bleser@opensuse.org
- update to 1.7:
  * rewritten settings code, splitting the /set command into a /set for global
    and a /hset for hub-local settings
  * file downloads are now performed in a background thread
  * the flush_file_cache setting has been improved
* Thu Dec  8 2011 pascal.bleser@opensuse.org
- update to 1.6:
  * use SQLite3 for storage instead of GDBM
  * converted config.ini to SQLite3 database
  * added ncdc-db-upgrade utility
  * session directory is architecture-independent
  * all data is safe against crashes and power failures
  * added support for removing/adding directories without rehashing
  * always match every file list on 'Q' key on TTH search
  * immediately flush log entries to the kernel
  * faster start-up
  * added support for per-hub 'active_ip' settings
  * allow interval notation when setting autorefresh
  * broadcast SF (number of shared files) on ADC hubs
  * combine TTH data for downloaded files to blocks of at least 1MiB
  * increased hash buffer size (10KiB -> 512KiB)
  * fix case-insensitivity of search results
  * fix reporting of user state in pm tabs at hub disconnect
  * fix generation of client certificates with openssl
  * fix segfault with duplicate users on an ADC hub
  * fix segfault when opening of a filelist fails
  * fix base32 decoding bug (fixes login sequence on some ADC hubs)
* Thu Nov  3 2011 pascal.bleser@opensuse.org
- add a patch to add missing includes, fixes build on 11.3
* Thu Nov  3 2011 pascal.bleser@opensuse.org
- update to 1.5:
  * adds a key to the search results to download and match a user's file list
    against the download queue
  * improves grant management
  * can avoid trashing the OS disk cache by issuing the posix_fadvise() call
* Thu Oct 27 2011 pascal.bleser@opensuse.org
- update to 1.4:
  * added sorting functionality to file list
  * added color settings: title, separator, list_default, list_header and
    list_select
  * added "blink" color attribute
  * allow /disconnect to be used on the main tab
  * display number of matched and added items when using match queue feature
  * use git-describe to create a version string, if available
  * decreased memory usage for large file lists
  * handle duplicate filenames in other users' file list
  * fixed incorrect setting of the "Incomplete" flag in files.xml.bz2
  * fixed handling of the PM param in MSG commands on ADC
  * fixed user change notifications for PM tabs
* Sat Oct 15 2011 pascal.bleser@opensuse.org
- update to 1.3:
  * adds multi-source downloading capabilities: an interface to manage the
    multiple sources for every file in the download queue was added, in
    addition to the ability to search for alternative sources and match file
    lists against the queue
- changes from 1.2:
  * fixed incorrect handling of outgoing NMDC connections
- changes from 1.1:
  * select item in file browser when opened from a search result
  * added active_bind setting
  * added share_exclude setting
  * added download_exclude setting
  * added incoming_dir setting
  * added autocompletion for the previous values of certain settings
  * allow the "connection" setting to be used for ADC as well
  * added IP column to user list
  * allow sorting on description, email, tag and IP columns in user list
  * display upload speeds in the user list of an ADC hub
  * added TLS indication to connection list
  * mark selected items bold in listings
  * allow /reconnect on the main tab to reconnect all hubs
  * added slash to base path in partial file lists
  * added delay of 5 seconds before reconnecting to a hub
  * added recognition of the AP param on ADC
  * added support for UserIP2 on NMDC
  * removed support for unexpected incoming NMDC connections
* Mon Sep 26 2011 pascal.bleser@opensuse.org
- drop ncdc-fix_missing_includes.patch, fixed upstream
- update to 1.0:
  * added ncdc(1) and ncdc-gen-cert(1) manual pages
  * documented settings (/help set <setting>)
  * documented key bindings (/help keys)
  * improved line wrapping algorithm for the log window
  * added support for client-to-client TLS on NMDC
  * added support for the CGFI command on ADC
  * throttle GET requests on the same file + offset
  * fixed downloading from clients using $ADCSND with -1 bytes
  * fixed race condition in file uploading code
  * fixed idle time calculation while connecting to another client
* Sat Sep  3 2011 pascal.bleser@opensuse.org
- update to 0.9:
  * added TLS support (adcs://, nmdcs://, and ADC client-to-client)
  * added tls_policy setting
  * added KEYP support for ADC
  * added warning when a hub changes TLS certificate
  * display exact listen ports when enabling active mode
* Fri Aug 26 2011 pascal.bleser@opensuse.org
- update to 0.8:
  * adds transfer logging
  * adds common readline keys for text input
  * adds day changed indicators in the log window
  * improved support for join messages
  * improved log rotation
* Wed Aug 17 2011 pascal.bleser@opensuse.org
- update to 0.7:
  * added word wrapping for the log window
  * added basic colors and nick highlighting to the log window
  * allow colors to be changed with the /set command
  * added backlog feature and setting
  * added silent building to the configure script
  * automatically re-open log files when they are moved/truncated externally
  * accept 'nmdc://' URLs as alternative to 'dchub://'
  * fixed spamming of useless $MyINFO and BINF commands every 5 minutes
  * fixed minor memory leak when closing/clearing the log window
* Tue Aug  9 2011 pascal.bleser@opensuse.org
- update to 0.6:
  * added file searching, through a /search command
  * added tab to display the search results
  * listen for incoming messages on UDP in active mode
  * allow specifying a hub address with /open
  * fixed case-sensitivity of shared files
  * various bugfixes and other improvements
* Wed Aug  3 2011 pascal.bleser@opensuse.org
- update to 0.5:
  * downloaded files are now TTH-checked
  * added download queue priorities
  * download queue items are automatically disabled on error
  * improved error handling and reporting for downloads
  * added download_slots setting
  * use a separate thread to load other users' file list
  * improved /gc to also clean up download queue related data
  * decreased memory usage for large file lists
  * improved error handling with sendfile()
  * fixed downloading in passive mode on ADC hubs
  * fixed adding a dir to the download queue while connected to the user
  * fixed segfault when the userlist is open while disconnecting from a hub
* Sat Jul 23 2011 pascal.bleser@opensuse.org
- update to 0.4:
  * single-source file downloading support
  * persistent download queue
  * improved connection manager
  * fixes a few crashes and other bugs
* Thu Jul 21 2011 pascal.bleser@opensuse.org
- update to 0.3:
  * added file list browser
  * added downloading of other people's file list
  * added 'hubname' setting to rename hub tabs
  * added -v, -c and -n commandline options
  * added -n option to /open to prevent an autoconnect
  * added referer notification
  * improved handling of some ADC commands
  * improved logging of debug messages
  * fixed error when uploading an empty file list
  * fixed display of join/quits on ADC hubs
  * fixed several crashes
- changes from 0.2:
  * ADC support
  * added slot granting and /grant command
  * added /kick (for NMDC hubs)
  * added /pm and /nick aliasses
  * added support for passworded login
  * added /me command (mostly useful for ADC hubs)
  * added /whois command
  * added 'share_hidden' option (default: false)
  * improved minislots support
  * added 'minislots' and 'minislot_size' options
  * slightly improved user list and connection list
  * /set displays default values for unset options
* Wed Jun 22 2011 pascal.bleser@opensuse.org
- initial version (0.1)
